@@ -19,10 +19,6 @@
 
 #include "fm.h"
 
-#ifdef COMPONENT_TAGGING
-#include <MauiKit/FileTagging/tagging.h>
-#endif
-
 #ifdef COMPONENT_SYNCING
 #include "syncing.h"
 #endif
@@ -34,8 +30,7 @@
 #include <QUrl>
 #include <QDebug>
 
-#if defined(Q_OS_ANDROID)
-#elif defined Q_OS_LINUX
+#ifdef KIO_AVAILABLE
 #include <KCoreDirLister>
 #include <KFileItem>
 #include <KFilePlacesModel>
@@ -44,11 +39,9 @@
 #include <KIO/MkdirJob>
 #include <KIO/SimpleJob>
 #include <QIcon>
-#endif
+#else
 
-#if defined(Q_OS_ANDROID) || defined(Q_OS_WIN) || defined(Q_OS_MACOS)
 #include "fileloader.h"
-
 #include <QFileSystemWatcher>
 
 QDirLister::QDirLister(QObject *parent)
@@ -186,7 +179,9 @@ bool QDirLister::openUrl(const QUrl &url)
         QDir::Filters dirFilter = (m_dirOnly ? QDir::AllDirs | QDir::NoDotDot | QDir::NoDot : QDir::Files | QDir::AllDirs | QDir::NoDotDot | QDir::NoDot);
 
         if (m_showDotFiles)
-            dirFilter = dirFilter | QDir::Hidden | QDir::System;
+        {
+            dirFilter = dirFilter | QDir::Hidden;
+        }
 
         m_loader->requestPath({this->m_url}, false, m_nameFilters.isEmpty() ? QStringList() : m_nameFilters.split(" "), dirFilter);
 
@@ -217,17 +212,14 @@ FM::FM(QObject *parent)
 #ifdef COMPONENT_SYNCING
     , sync(new Syncing(this))
 #endif
-#ifdef COMPONENT_TAGGING
-    , tag(Tagging::getInstance())
-#endif
-#if defined(Q_OS_LINUX) && !defined(Q_OS_ANDROID)
+#ifdef KIO_AVAILABLE
     , dirLister(new KCoreDirLister(this))
 #else
-    , dirLister(new QDirLister)
+    , dirLister(new QDirLister(this))
 #endif
 {
 
-#if defined(Q_OS_LINUX) && !defined(Q_OS_ANDROID)
+#ifdef KIO_AVAILABLE
     this->dirLister->setAutoUpdate(true);
 
     const static auto packItems = [](const KFileItemList &items) -> FMH::MODEL_LIST {
@@ -237,7 +229,12 @@ FM::FM(QObject *parent)
         });
     };
 
-    connect(dirLister, static_cast<void (KCoreDirLister::*)(const QUrl &)>(&KCoreDirLister::completed), this, [&](QUrl url) {
+    connect(dirLister, static_cast<void (KCoreDirLister::*)(const QUrl &)>(&KCoreDirLister::listingDirCompleted), this, [&](QUrl url) {
+        qDebug() << "PATH CONTENT READY" << url;
+        emit this->pathContentReady(url);
+    });
+    
+    connect(dirLister, static_cast<void (KCoreDirLister::*)(const QUrl &)>(&KCoreDirLister::listingDirCanceled), this, [&](QUrl url) {
         qDebug() << "PATH CONTENT READY" << url;
         emit this->pathContentReady(url);
     });
@@ -247,14 +244,14 @@ FM::FM(QObject *parent)
         emit this->pathContentItemsReady({dirUrl, packItems(items)});
     });
 
-    //    connect(dirLister, static_cast<void (KCoreDirLister::*)(const KFileItemList &items)>(&KCoreDirLister::newItems), [&](KFileItemList items)
-    //    {
-    //        qDebug()<< "MORE NEW ITEMS WERE ADDED";
-    //        for(const auto &item : items)
-    //            qDebug()<< "MORE <<" << item.url();
-    //
-    //        emit this->pathContentChanged(dirLister->url());
-    //    });
+//        connect(dirLister, static_cast<void (KCoreDirLister::*)(const KFileItemList &items)>(&KCoreDirLister::newItems), [&](KFileItemList items)
+//        {
+//            qDebug()<< "MORE NEW ITEMS WERE ADDED";
+//            for(const auto &item : items)
+//                qDebug()<< "MORE <<" << item.url();
+//     
+//            emit this->pathContentChanged(dirLister->url());
+//        });
 
     connect(dirLister, static_cast<void (KCoreDirLister::*)(const KFileItemList &items)>(&KCoreDirLister::itemsDeleted), this, [&](KFileItemList items) {
         qDebug() << "ITEMS WERE DELETED";
@@ -359,6 +356,11 @@ void FM::getPathContent(const QUrl &path, const bool &hidden, const bool &onlyDi
 
 bool FM::getCloudServerContent(const QUrl &path, const QStringList &filters, const int &depth)
 {
+    Q_UNUSED(path)
+    Q_UNUSED(filters)    
+    Q_UNUSED(depth)
+    
+    
 #ifdef COMPONENT_SYNCING
     const auto __list = path.toString().replace("cloud:///", "/").split("/");
 
@@ -389,6 +391,9 @@ bool FM::getCloudServerContent(const QUrl &path, const QStringList &filters, con
 
 void FM::createCloudDir(const QString &path, const QString &name)
 {
+    Q_UNUSED(path)
+    Q_UNUSED(name)
+    
 #ifdef COMPONENT_SYNCING
     this->sync->createDir(path, name);
 #endif
@@ -396,6 +401,8 @@ void FM::createCloudDir(const QString &path, const QString &name)
 
 void FM::openCloudItem(const QVariantMap &item)
 {
+    Q_UNUSED(item)
+    
 #ifdef COMPONENT_SYNCING
     FMH::MODEL data;
     const auto keys = item.keys();
@@ -408,6 +415,7 @@ void FM::openCloudItem(const QVariantMap &item)
 
 void FM::getCloudItem(const QVariantMap &item)
 {
+    Q_UNUSED(item)    
 #ifdef COMPONENT_SYNCING
     this->sync->resolveFile(FMH::toModel(item), Syncing::SIGNAL_TYPE::DOWNLOAD);
 #endif
@@ -421,6 +429,7 @@ QString FM::resolveUserCloudCachePath(const QString &server, const QString &user
 
 QString FM::resolveLocalCloudPath(const QString &path)
 {
+    Q_UNUSED(path)
 #ifdef COMPONENT_SYNCING
     return QString(path).replace(FMStatic::PATHTYPE_URI[FMStatic::PATHTYPE_KEY::CLOUD_PATH] + this->sync->getUser(), "");
 #else
