@@ -26,10 +26,7 @@
 #include <MauiKit/syncing.h>
 #endif
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-#include <KIO/EmptyTrashJob>
-#endif
-
+#include <QHash>
 #include <QFuture>
 #include <QObject>
 #include <QThread>
@@ -41,20 +38,20 @@ FMList::FMList(QObject *parent)
     , fm(new FM(this))
 {
     qRegisterMetaType<FMList *>("const FMList*"); // this is needed for QML to know of FMList in the search method
-    connect(this->fm, &FM::cloudServerContentReady, [&](const FMH::MODEL_LIST &list, const QUrl &url) {
+    connect(this->fm, &FM::cloudServerContentReady, [this](const FMH::MODEL_LIST &list, const QUrl &url) {
         if (this->path == url) {
             this->assignList(list);
         }
     });
 
-    connect(this->fm, &FM::pathContentReady, [&](QUrl) {
+    connect(this->fm, &FM::pathContentReady, [this](QUrl) {
         emit this->preListChanged();
         this->sortList();
         this->setStatus({PathStatus::STATUS_CODE::READY, this->list.isEmpty() ? "Nothing here!" : "", this->list.isEmpty() ? "This place seems to be empty" : "", this->list.isEmpty() ? "folder-add" : "", this->list.isEmpty(), true});
         emit this->postListChanged();
     });
 
-    connect(this->fm, &FM::pathContentItemsChanged, [&](QVector<QPair<FMH::MODEL, FMH::MODEL>> res) {
+    connect(this->fm, &FM::pathContentItemsChanged, [this](QVector<QPair<FMH::MODEL, FMH::MODEL>> res) {
         for (const auto &item : qAsConst(res)) {
             const auto index = this->indexOf(FMH::MODEL_KEY::PATH, item.first[FMH::MODEL_KEY::PATH]);
 
@@ -66,14 +63,14 @@ FMList::FMList(QObject *parent)
         }
     });
 
-    connect(this->fm, &FM::pathContentItemsReady, [&](FMStatic::PATH_CONTENT res) {
+    connect(this->fm, &FM::pathContentItemsReady, [this](FMStatic::PATH_CONTENT res) {
         if (res.path != this->path)
             return;
 
         this->appendToList(res.content);
     });
 
-    connect(this->fm, &FM::pathContentItemsRemoved, [&](FMStatic::PATH_CONTENT res) {
+    connect(this->fm, &FM::pathContentItemsRemoved, [this](FMStatic::PATH_CONTENT res) {
         if (res.path != this->path)
             return;
 
@@ -92,22 +89,22 @@ FMList::FMList(QObject *parent)
         this->setStatus({PathStatus::STATUS_CODE::READY, this->list.isEmpty() ? "Nothing here!" : "", this->list.isEmpty() ? "This place seems to be empty" : "", this->list.isEmpty() ? "folder-add" : "", this->list.isEmpty(), true});
     });
 
-    connect(this->fm, &FM::warningMessage, [&](const QString &message) {
+    connect(this->fm, &FM::warningMessage, [this](const QString &message) {
         emit this->warning(message);
     });
 
-    connect(this->fm, &FM::loadProgress, [&](const int &percent) {
+    connect(this->fm, &FM::loadProgress, [this](const int &percent) {
         emit this->progress(percent);
     });
 
-    connect(this->fm, &FM::pathContentChanged, [&](const QUrl &path) {
+    connect(this->fm, &FM::pathContentChanged, [this](const QUrl &path) {
         qDebug() << "FOLDER PATH CHANGED" << path;
         if (path != this->path)
             return;
         this->sortList();
     });
 
-    connect(this->fm, &FM::newItem, [&](const FMH::MODEL &item, const QUrl &url) {
+    connect(this->fm, &FM::newItem, [this](const FMH::MODEL &item, const QUrl &url) {
         if (this->path == url) {
             emit this->preItemAppended();
             this->list << item;
@@ -117,10 +114,15 @@ FMList::FMList(QObject *parent)
     
     connect(Tagging::getInstance(), &Tagging::urlTagged, [this](QString, QString tag)
     {
-        if(this->path.toString().endsWith(tag))
+        if(this->getPathType() == FMList::PATHTYPE::TAGS_PATH)
         {
-            this->refresh();
+            const auto url = this->path.toString();
+            if(url.endsWith(tag))
+            {
+                this->refresh();
+            }
         }
+
     });
     
     connect(Tagging::getInstance(), &Tagging::tagged, [this](QVariantMap)
@@ -129,7 +131,7 @@ FMList::FMList(QObject *parent)
         {
             this->refresh();
         }
-    });
+    });   
 }
 
 void FMList::assignList(const FMH::MODEL_LIST &list)
@@ -174,7 +176,7 @@ void FMList::setList()
 {
     qDebug() << "PATHTYPE FOR URL" << pathType << this->path.toString() << this->filters << this;
     this->clear();
-
+       
     switch (this->pathType) {
     case FMList::PATHTYPE::TAGS_PATH:
         this->assignList(getTagContent(this->path.fileName(), QStringList() << this->filters << FMStatic::FILTER_LIST[static_cast<FMStatic::FILTER_TYPE>(this->filterType)]));
@@ -216,114 +218,72 @@ void FMList::setSortBy(const FMList::SORTBY &key)
     if (this->sort == key)
         return;
 
-    emit this->preListChanged();
-
     this->sort = key;
-    this->sortList();
-
-    emit this->sortByChanged();
-    emit this->postListChanged();
+    emit this->sortByChanged();      
 }
 
 void FMList::sortList()
 {
     const FMH::MODEL_KEY key = static_cast<FMH::MODEL_KEY>(this->sort);
-    auto index = 0;
-
-    if (this->foldersFirst) {
-        qSort(this->list.begin(), this->list.end(), [](const FMH::MODEL &e1, const FMH::MODEL &e2) -> bool {
-            Q_UNUSED(e2)
-            const auto key = FMH::MODEL_KEY::MIME;
-            return e1[key] == "inode/directory";
-        });
-
-        for (const auto &item : qAsConst(this->list))
-            if (item[FMH::MODEL_KEY::MIME] == "inode/directory")
-                index++;
-            else
-                break;
-
-        std::sort(this->list.begin(), this->list.begin() + index, [&key](const FMH::MODEL &e1, const FMH::MODEL &e2) -> bool {
-            switch (key) {
+    auto it = this->list.begin();
+    
+    const auto sortFunc = [key](const FMH::MODEL &e1, const FMH::MODEL &e2) -> bool
+    {
+        switch (key) {
             case FMH::MODEL_KEY::SIZE: {
                 if (e1[key].toDouble() > e2[key].toDouble())
                     return true;
                 break;
             }
-
+            
             case FMH::MODEL_KEY::MODIFIED:
             case FMH::MODEL_KEY::DATE: {
                 auto currentTime = QDateTime::currentDateTime();
-
+                
                 auto date1 = QDateTime::fromString(e1[key], Qt::TextDate);
                 auto date2 = QDateTime::fromString(e2[key], Qt::TextDate);
-
+                
                 if (date1.secsTo(currentTime) < date2.secsTo(currentTime))
                     return true;
-
+                
                 break;
             }
-
+            
             case FMH::MODEL_KEY::LABEL: {
                 const auto str1 = QString(e1[key]).toLower();
                 const auto str2 = QString(e2[key]).toLower();
-
+                
                 if (str1 < str2)
                     return true;
                 break;
             }
-
+            
             default:
                 if (e1[key] < e2[key])
                     return true;
-            }
+        }
+        
+        return false;
+    };    
 
-            return false;
-        });
+    if (this->foldersFirst) {         
+        
+        it = std::partition(this->list.begin(),
+                                  this->list.end(),
+                                  [](const FMH::MODEL &e1) -> bool {
+                                      return e1[FMH::MODEL_KEY::MIME] == "inode/directory";
+                                  });
+
+        if(this->list.begin() != it)
+        {
+            std::sort(this->list.begin(), it, sortFunc);
+        }
     }
 
-    std::sort(this->list.begin() + index, this->list.end(), [key](const FMH::MODEL &e1, const FMH::MODEL &e2) -> bool {
-        switch (key) {
-        case FMH::MODEL_KEY::MIME:
-            if (e1[key] == "inode/directory")
-                return true;
-            break;
-
-        case FMH::MODEL_KEY::SIZE: {
-            if (e1[key].toDouble() > e2[key].toDouble())
-                return true;
-            break;
-        }
-
-        case FMH::MODEL_KEY::MODIFIED:
-        case FMH::MODEL_KEY::DATE: {
-            auto currentTime = QDateTime::currentDateTime();
-
-            auto date1 = QDateTime::fromString(e1[key], Qt::TextDate);
-            auto date2 = QDateTime::fromString(e2[key], Qt::TextDate);
-
-            if (date1.secsTo(currentTime) < date2.secsTo(currentTime))
-                return true;
-
-            break;
-        }
-
-        case FMH::MODEL_KEY::LABEL: {
-            const auto str1 = QString(e1[key]).toLower();
-            const auto str2 = QString(e2[key]).toLower();
-
-            if (str1 < str2)
-                return true;
-            break;
-        }
-
-        default:
-            if (e1[key] < e2[key])
-                return true;
-        }
-
-        return false;
-    });
+    if(it != this->list.end())
+    {
+        std::sort(it, this->list.end(), sortFunc);
+    }    
 }
 
 QString FMList::getPathName() const
@@ -384,7 +344,7 @@ void FMList::setPath(const QUrl &path)
 
     emit this->pathNameChanged();
     emit this->pathTypeChanged();
-    emit this->pathChanged();
+    emit this->pathChanged();   
 }
 
 FMList::PATHTYPE FMList::getPathType() const
@@ -475,11 +435,7 @@ void FMList::copyInto(const QStringList &urls)
 
 void FMList::cutInto(const QStringList &urls)
 {
-    this->fm->cut(QUrl::fromStringList(urls), this->path);
-    // 	else if(this->pathType == FMList::PATHTYPE::CLOUD_PATH)
-    // 	{
-    // 		this->fm->createCloudDir(QString(this->path).replace(FMH::PATHTYPE_NAME[FMList::PATHTYPE::CLOUD_PATH]+"/"+this->fm->sync->getUser(), ""), name);
-    // 	}
+    this->fm->cut(QUrl::fromStringList(urls), this->path);  
 }
 
 void FMList::setDirIcon(const int &index, const QString &iconName)
@@ -487,8 +443,6 @@ void FMList::setDirIcon(const int &index, const QString &iconName)
     if (index >= this->list.size() || index < 0)
         return;
 
-    //    const auto index_ = this->mappedIndex(index);
-
     const auto path = QUrl(this->list.at(index)[FMH::MODEL_KEY::PATH]);
 
     if (!FMStatic::isDir(path))
@@ -563,7 +517,17 @@ void FMList::componentComplete()
     connect(this, &FMList::filterTypeChanged, this, &FMList::setList);
     connect(this, &FMList::hiddenChanged, this, &FMList::setList);
     connect(this, &FMList::onlyDirsChanged, this, &FMList::setList);
-
+    
+    connect(this, &FMList::sortByChanged, [this]()
+    {    
+        if(this->list.size() > 0)
+        {
+            emit this->preListChanged();        
+            this->sortList();        
+            emit this->postListChanged();
+        }       
+    });
+   
     this->setList();
 }
 
@@ -668,12 +632,13 @@ void FMList::remove(const int &index)
 
 int FMList::indexOfName(const QString& query)
 {
-     const auto it = std::find_if(this->items().constBegin(), this->items().constEnd(), [&](const FMH::MODEL &item) -> bool {
+     const auto it = std::find_if(this->items().constBegin(), this->items().constEnd(), [query](const FMH::MODEL &item) -> bool {
         return item[FMH::MODEL_KEY::LABEL].startsWith(query, Qt::CaseInsensitive);
     });
 
     if (it != this->items().constEnd())
-        return this->mappedIndexFromSource(std::distance(this->items().constBegin(), it));
+        return (std::distance(this->items().constBegin(), it));
     else
         return -1;
 }
+
