@@ -5,19 +5,24 @@
 #include <QDesktopServices>
 #include <QDirIterator>
 #include <QFileInfo>
+#include <QDateTime>
+#include <QSettings>
 
 #if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-#include <KCoreDirLister>
+#include <KConfig>
+#include <KConfigGroup>
+#endif
+
+#ifdef KIO_AVAILABLE
 #include <KIO/CopyJob>
 #include <KIO/DeleteJob>
 #include <KIO/EmptyTrashJob>
 #include <KIO/MkdirJob>
 #include <KIO/SimpleJob>
-#include <KConfig>
-#include <KConfigGroup>
-#include <KRun>
+#include <KIO/OpenUrlJob>
 #include <KApplicationTrader>
-#include <QIcon>
+#include <KIO/PreviewJob>
+#include <KFileItem>
 #endif
 
 FMStatic::FMStatic(QObject *parent)
@@ -127,15 +132,15 @@ bool FMStatic::fileExists(const QUrl &path)
     return FMH::fileExists(path);
 }
 
-QString FMStatic::fileDir(const QUrl &path) // the directory path of the file
+QUrl FMStatic::fileDir(const QUrl &path) // the directory path of the file
 {
-    QString res = path.toString();
+    QUrl res = path;
     if (path.isLocalFile()) {
         const QFileInfo file(path.toLocalFile());
         if (file.isDir())
-            res = path.toString();
+            res = path;
         else
-            res = QUrl::fromLocalFile(file.dir().absolutePath()).toString();
+            res = QUrl::fromLocalFile(file.dir().absolutePath());
     } else
         qWarning() << "The path is not a local one. FM::fileDir";
     
@@ -146,7 +151,7 @@ QString FMStatic::homePath()
 {
     return FMStatic::HomePath;
 }
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
+#if !defined KIO_AVAILABLE
 
 static bool copyRecursively(QString sourceFolder, QString destFolder)
 {
@@ -185,8 +190,12 @@ static bool copyRecursively(QString sourceFolder, QString destFolder)
 
 bool FMStatic::copy(const QList<QUrl> &urls, const QUrl &destinationDir)
 {
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
-    for (const auto &url : urls) {
+#ifdef KIO_AVAILABLE
+    auto job = KIO::copy(urls, destinationDir);
+    job->start();
+    return true;
+#else
+    for (const auto &url : std::as_const(urls)) {
         QFileInfo srcFileInfo(url.toLocalFile());
         if (!srcFileInfo.isDir() && srcFileInfo.isFile()) {
             const auto _destination = QUrl(destinationDir.toString() + "/" + FMStatic::getFileInfoModel(url)[FMH::MODEL_KEY::LABEL]);
@@ -204,10 +213,6 @@ bool FMStatic::copy(const QList<QUrl> &urls, const QUrl &destinationDir)
         }
     }
     return true;
-#else
-    auto job = KIO::copy(urls, destinationDir);
-    job->start();
-    return true;
 #endif
 }
 
@@ -218,20 +223,7 @@ bool FMStatic::cut(const QList<QUrl> &urls, const QUrl &where)
 
 bool FMStatic::cut(const QList<QUrl> &urls, const QUrl &where, const QString &name)
 {
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
-    for (const auto &url : qAsConst(urls)) {
-        QUrl _where;
-        if (name.isEmpty())
-            _where = QUrl(where.toString() + "/" + FMStatic::getFileInfoModel(url)[FMH::MODEL_KEY::LABEL]);
-        else
-            _where = QUrl(where.toString() + "/" + name);
-
-        QFile file(url.toLocalFile());
-        file.rename(_where.toLocalFile());
-
-        Tagging::getInstance()->updateUrl(url.toString(), _where.toString());
-    }
-#else
+#ifdef KIO_AVAILABLE
     QUrl _where = where;
     if (!name.isEmpty())
         _where = QUrl(where.toString() + "/" + name);
@@ -246,6 +238,19 @@ bool FMStatic::cut(const QList<QUrl> &urls, const QUrl &where, const QString &na
 
         Tagging::getInstance()->updateUrl(url.toString(), where_.toString());
     }
+#else
+    for (const auto &url : std::as_const(urls)) {
+        QUrl _where;
+        if (name.isEmpty())
+            _where = QUrl(where.toString() + "/" + FMStatic::getFileInfoModel(url)[FMH::MODEL_KEY::LABEL]);
+        else
+            _where = QUrl(where.toString() + "/" + name);
+
+        QFile file(url.toLocalFile());
+        file.rename(_where.toLocalFile());
+
+        Tagging::getInstance()->updateUrl(url.toString(), _where.toString());
+    }
 #endif
 
     return true;
@@ -253,14 +258,17 @@ bool FMStatic::cut(const QList<QUrl> &urls, const QUrl &where, const QString &na
 
 bool FMStatic::removeFiles(const QList<QUrl> &urls)
 {
-    for (const auto &url : qAsConst(urls)) {
+    for (const auto &url : std::as_const(urls)) {
         Tagging::getInstance()->removeUrl(url.toString());
     }
 
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
-
+#ifdef KIO_AVAILABLE
+    auto job = KIO::del(urls);
+    job->start();
+    return true;
+#else
     qDebug() << "ASKED GTO DELETE FILES" << urls;
-    for (const auto &url : qAsConst(urls)) {
+    for (const auto &url : std::as_const(urls)) {
         qDebug() << "@ Want to remove files << " << url.toLocalFile();
 
         if (isDir(url)) {
@@ -272,16 +280,12 @@ bool FMStatic::removeFiles(const QList<QUrl> &urls)
         }
     }
     return true;
-#else
-    auto job = KIO::del(urls);
-    job->start();
-    return true;
 #endif
 }
 
 void FMStatic::moveToTrash(const QList<QUrl> &urls)
 {
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#ifdef KIO_AVAILABLE
     auto job = KIO::trash(urls);
     job->start();
 #else
@@ -291,7 +295,7 @@ void FMStatic::moveToTrash(const QList<QUrl> &urls)
 
 void FMStatic::emptyTrash()
 {
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#ifdef KIO_AVAILABLE
     auto job = KIO::emptyTrash();
     job->start();
 #endif
@@ -327,13 +331,12 @@ bool FMStatic::rename(const QUrl &url, const QString &name)
 
 bool FMStatic::createDir(const QUrl &path, const QString &name)
 {
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
-    QFileInfo dd(path.toLocalFile());
-    return QDir(path.toLocalFile()).mkdir(name);
-#else
+#ifdef KIO_AVAILABLE
     auto job = KIO::mkdir(name.isEmpty() ? path : QUrl(path.toString() + "/" + name));
     job->start();
     return true;
+#else
+    return QDir(path.toLocalFile()).mkdir(name);
 #endif
 }
 
@@ -351,99 +354,72 @@ bool FMStatic::createFile(const QUrl &path, const QString &name)
 
 bool FMStatic::createSymlink(const QUrl &path, const QUrl &where)
 {
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
-    return QFile::link(path.toLocalFile(), where.toLocalFile() + "/" + QFileInfo(path.toLocalFile()).fileName());
-#else
+#ifdef KIO_AVAILABLE
     qDebug() << "trying to create symlink" << path << where;
     const auto job = KIO::link({path}, where);
     job->start();
     return true;
+#else
+    return QFile::link(path.toLocalFile(), where.toLocalFile() + "/" + QFileInfo(path.toLocalFile()).fileName());
 #endif
 }
 
-bool FMStatic::openUrl(const QUrl &url)
+void FMStatic::openUrl(const QUrl &url)
 {
+#ifdef KIO_AVAILABLE
+    KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
+    job->setShowOpenOrExecuteDialog(true);
+    job->start();
+#else
+
 #if defined Q_OS_ANDROID
     MAUIAndroid::openUrl(url.toString());
-    return true;
-#elif defined Q_OS_LINUX && !defined Q_OS_ANDROID
-    const QMimeDatabase mimedb;
-    KRun::runUrl(url, mimedb.mimeTypeForFile(url.toLocalFile()).name(), nullptr, false, KRun::RunFlag::DeleteTemporaryFiles);
-#elif defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
-    return QDesktopServices::openUrl(url);
+#else
+    QDesktopServices::openUrl(url);
 #endif
     
-    return true;
+#endif    
 }
 
 void FMStatic::openLocation(const QStringList &urls)
 {
     for (const auto &url : qAsConst(urls))
-        QDesktopServices::openUrl(QUrl::fromLocalFile(QFileInfo(url).dir().absolutePath()));
+    {
+        if(isDir(url))
+        {
+            QDesktopServices::openUrl(url);
+        }else
+        {
+            QDesktopServices::openUrl(fileDir(url));
+        }
+    }
 }
 
-const QVariantMap FMStatic::dirConf(const QUrl &path)
+const QString FMStatic::dirConfIcon(const QUrl &path)
 {
+    QString icon = "folder";
+    
     if (!path.isLocalFile()) {
         qWarning() << "URL recived is not a local file" << path;
-        return QVariantMap();
+        return icon;
     }
     
     if (!fileExists(path))
-        return QVariantMap();
+        return icon;
     
-    QString icon, iconsize, hidden, detailview, showthumbnail, showterminal;
-    
-    uint count = 0, sortby = FMH::MODEL_KEY::MODIFIED, viewType = 0;
-    
-    bool foldersFirst = false;
     
 #if defined Q_OS_ANDROID || defined Q_OS_WIN || defined Q_OS_MACOS || defined Q_OS_IOS
     QSettings file(path.toLocalFile(), QSettings::Format::NativeFormat);
     file.beginGroup(QString("Desktop Entry"));
     icon = file.value("Icon").toString();
     file.endGroup();
-    
-    file.beginGroup(QString("Settings"));
-    hidden = file.value("HiddenFilesShown").toString();
-    file.endGroup();
-    
-    file.beginGroup(QString("MAUIFM"));
-    iconsize = file.value("IconSize").toString();
-    detailview = file.value("DetailView").toString();
-    showthumbnail = file.value("ShowThumbnail").toString();
-    showterminal = file.value("ShowTerminal").toString();
-    count = file.value("Count").toInt();
-    sortby = file.value("SortBy").toInt();
-    foldersFirst = file.value("FoldersFirst").toBool();
-    viewType = file.value("ViewType").toInt();
-    file.endGroup();
-    
 #else
     KConfig file(path.toLocalFile());
-    icon = file.entryMap(QString("Desktop Entry"))["Icon"];
-    hidden = file.entryMap(QString("Settings"))["HiddenFilesShown"];
-    iconsize = file.entryMap(QString("MAUIFM"))["IconSize"];
-    detailview = file.entryMap(QString("MAUIFM"))["DetailView"];
-    showthumbnail = file.entryMap(QString("MAUIFM"))["ShowThumbnail"];
-    showterminal = file.entryMap(QString("MAUIFM"))["ShowTerminal"];
-    count = file.entryMap(QString("MAUIFM"))["Count"].toInt();
-    sortby = file.entryMap(QString("MAUIFM"))["SortBy"].toInt();
-    foldersFirst = file.entryMap(QString("MAUIFM"))["FoldersFirst"] == "true" ? true : false;
-    viewType = file.entryMap(QString("MAUIFM"))["ViewType"].toInt();
+    const auto map = file.entryMap(QString("Desktop Entry"));
+    icon = map.isEmpty() ? "folder" : map.value("Icon");
 #endif
     
-    return QVariantMap({{FMH::MODEL_NAME[FMH::MODEL_KEY::ICON], icon.isEmpty() ? "folder" : icon},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::ICONSIZE], iconsize},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::COUNT], count},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::SHOWTERMINAL], showterminal.isEmpty() ? "false" : showterminal},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::SHOWTHUMBNAIL], showthumbnail.isEmpty() ? "false" : showthumbnail},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::DETAILVIEW], detailview.isEmpty() ? "false" : detailview},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::HIDDEN], hidden.isEmpty() ? false : (hidden == "true" ? true : false)},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::SORTBY], sortby},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::FOLDERSFIRST], foldersFirst},
-                        {FMH::MODEL_NAME[FMH::MODEL_KEY::VIEWTYPE], viewType}});
-    
+    return icon;
 }
 
 void FMStatic::setDirConf(const QUrl &path, const QString &group, const QString &key, const QVariant &value)
@@ -506,10 +482,14 @@ const QString FMStatic::getMime(const QUrl &path)
 
 static const QUrl thumbnailUrl(const QUrl &url, const QString &mimetype)
 {
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-    if (FMStatic::checkFileType(FMStatic::FILTER_TYPE::DOCUMENT, mimetype) || FMStatic::checkFileType(FMStatic::FILTER_TYPE::VIDEO, mimetype) || url.toString().endsWith(".appimage", Qt::CaseInsensitive)) {
+#ifdef KIO_AVAILABLE
+    if (FMStatic::checkFileType(FMStatic::FILTER_TYPE::FONT, mimetype) || FMStatic::checkFileType(FMStatic::FILTER_TYPE::TEXT, mimetype) || FMStatic::checkFileType(FMStatic::FILTER_TYPE::AUDIO, mimetype) || FMStatic::checkFileType(FMStatic::FILTER_TYPE::DOCUMENT, mimetype) || FMStatic::checkFileType(FMStatic::FILTER_TYPE::VIDEO, mimetype) || url.toString().endsWith(".appimage", Qt::CaseInsensitive)) {
         return QUrl("image://thumbnailer/" + url.toString());
     }
+    
+    //      if (KIO::PreviewJob::supportedMimeTypes().contains(mimetype)) {
+    //         return QUrl("image://thumbnailer/" + url.toString());
+    //     }
 #endif
     
     if (FMStatic::checkFileType(FMStatic::FILTER_TYPE::IMAGE, mimetype)) {
@@ -519,7 +499,7 @@ static const QUrl thumbnailUrl(const QUrl &url, const QString &mimetype)
     return QUrl();
 }
 
-#if (!defined Q_OS_ANDROID && defined Q_OS_LINUX)
+#ifdef KIO_AVAILABLE
 const FMH::MODEL FMStatic::getFileInfo(const KFileItem &kfile)
 {
     return FMH::MODEL {{FMH::MODEL_KEY::LABEL, kfile.name()},
@@ -550,7 +530,9 @@ const FMH::MODEL FMStatic::getFileInfo(const KFileItem &kfile)
         const FMH::MODEL FMStatic::getFileInfoModel(const QUrl &path)
         {
             FMH::MODEL res;
-#if defined Q_OS_ANDROID || defined Q_OS_MACOS || defined Q_OS_IOS || defined Q_OS_WIN
+#ifdef KIO_AVAILABLE
+            res = FMStatic::getFileInfo(KFileItem(path, KFileItem::MimeTypeDetermination::NormalMimeTypeDetermination));
+#else
             const QFileInfo file(path.toLocalFile());
             if (!file.exists())
                 return FMH::MODEL();
@@ -579,52 +561,39 @@ const FMH::MODEL FMStatic::getFileInfo(const KFileItem &kfile)
             {FMH::MODEL_KEY::URL, path.toString()},
             {FMH::MODEL_KEY::THUMBNAIL, thumbnailUrl(path, mime).toString()},
             {FMH::MODEL_KEY::COUNT, file.isDir() ? QString::number(QDir(path.toLocalFile()).count()) : "0"}};
-        #else
-            res = FMStatic::getFileInfo(KFileItem(path, KFileItem::MimeTypeDetermination::NormalMimeTypeDetermination));
-#endif
-            return res;
+        #endif
+                    return res;
         }
 
-        const QVariantMap FMStatic::getFileInfo(const QUrl &path)
-        {
-            return FMH::toMap(getFileInfoModel(path));
+                    const QVariantMap FMStatic::getFileInfo(const QUrl &path)
+            {
+                    return FMH::toMap(getFileInfoModel(path));
         }
 
-        const FMH::MODEL FMStatic::getDirInfoModel(const QUrl &path, const QString &type)
-        {
-            auto res = getFileInfoModel(path);
-            res[FMH::MODEL_KEY::TYPE] = type;
-            return res;
-        }
-
-        const QVariantMap FMStatic::getDirInfo(const QUrl &path)
-        {
-            return FMH::toMap(getDirInfoModel(path));
-        }
-
-        const QString FMStatic::getIconName(const QUrl &path)
-        {
-            if (path.isLocalFile() && QFileInfo(path.toLocalFile()).isDir()) {
-                if (folderIcon.contains(path.toString()))
+                    const QString FMStatic::getIconName(const QUrl &path)
+            {
+                    if (path.isLocalFile() && QFileInfo(path.toLocalFile()).isDir()) {
+                    if (folderIcon.contains(path.toString()))
                     return folderIcon[path.toString()];
-                else {
-                    const auto icon = dirConf(QString(path.toString() + "/%1").arg(".directory"))[FMH::MODEL_NAME[FMH::MODEL_KEY::ICON]].toString();
-                    return icon.isEmpty() ? "folder" : icon;
-                }
-
-            } else {
-#if defined Q_OS_ANDROID || defined Q_OS_MACOS || defined Q_OS_IOS || defined Q_OS_WIN
-                QMimeDatabase mime;
-                const auto type = mime.mimeTypeForFile(path.toString());
-                return type.iconName();
-#else
-                KFileItem mime(path);
-                return mime.iconName();
-#endif
-            }
+                    else {
+                    return dirConfIcon(QString(path.toString() + "/%1").arg(".directory"));
+        }
+                    
+        } else {
+        #ifdef KIO_AVAILABLE
+                    KFileItem mime(path);
+                    return mime.iconName();
+        #else
+                    QMimeDatabase mime;
+                    const auto type = mime.mimeTypeForFile(path.toString());
+                    return type.iconName();
+        #endif
+        }
         }
 
-        FMStatic::PATHTYPE_KEY FMStatic::getPathType(const QUrl &url)
-        {
-            return FMStatic::PATHTYPE_SCHEME_NAME[url.scheme()];
+                    FMStatic::PATHTYPE_KEY FMStatic::getPathType(const QUrl &url)
+            {
+                    return FMStatic::PATHTYPE_SCHEME_NAME[url.scheme()];
         }
+
+
