@@ -21,60 +21,46 @@
 #include "tagging.h"
 
 #include <QEventLoop>
-#include <QFileSystemWatcher>
 #include <QIcon>
 #include <QTimer>
 
 #include <MauiKit/Core/utils.h>
 #include <MauiKit/Core/fmh.h>
 
-#ifdef COMPONENT_ACCOUNTS
-#include <MauiKit/Core/mauiaccounts.h>
-#endif
-
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#ifdef KIO_AVAILABLE
 #include <KFilePlacesModel>
 #include <Solid/Device>
 #endif
 
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
+#ifdef KIO_AVAILABLE
+int FMStatic::mapPathType(const FMStatic::PATHTYPE_KEY& value)
+{
+    switch(value)
+    {
+        case PLACES_PATH: return KFilePlacesModel::GroupType::PlacesType;
+        case REMOTE_PATH: return KFilePlacesModel::GroupType::RemoteType;
+        case DRIVES_PATH: return KFilePlacesModel::GroupType::DevicesType;
+        case REMOVABLE_PATH: return KFilePlacesModel::GroupType::RemovableDevicesType;
+        case TAGS_PATH: return KFilePlacesModel::GroupType::TagsType;
+        case UNKNOWN_TYPE: return KFilePlacesModel::GroupType::UnknownType;
+        default: return value;
+    }
+}
+#endif
+
+
+#ifdef KIO_AVAILABLE
 PlacesList::PlacesList(QObject *parent)
     : MauiList(parent)
-    , fm(new FM(this))
-    , model(nullptr)
-    , watcher(new QFileSystemWatcher(this))
+    , model(new KFilePlacesModel(this))
     #else
 PlacesList::PlacesList(QObject *parent)
     : MauiList(parent)
-    , fm(new FM(this))
-    , model(new KFilePlacesModel(this))
-    , watcher(new QFileSystemWatcher(this))
+    , model(nullptr)
     #endif
 {
-    /*
-     *  The watcher signal returns a local file URL withouth a scheme, and the model is using a local file URL with file:// scheme.
-     *  So those need to be correctly mapped
-     * */
-    connect(watcher, &QFileSystemWatcher::directoryChanged, [&](const QString &path) {
-        if (this->count.contains(QUrl::fromLocalFile(path).toString())) {
-            const auto oldCount = this->count[QUrl::fromLocalFile(path).toString()];
-            const auto index = this->indexOf(FMH::MODEL_KEY::PATH, QUrl::fromLocalFile(path).toString());
-            const QDir dir(path);
-            const auto newCount = dir.count();
-            int count = newCount - oldCount;
 
-            this->list[index][FMH::MODEL_KEY::COUNT] = QString::number(std::max(0, count));
-            emit this->updateModel(index, {FMH::MODEL_KEY::COUNT});
-        }
-    });
-
-#ifdef COMPONENT_ACCOUNTS
-    connect(MauiAccounts::instance(), &MauiAccounts::accountAdded, this, &PlacesList::setList);
-    connect(MauiAccounts::instance(), &MauiAccounts::accountRemoved, this, &PlacesList::setList);
-#endif
-
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-    
+#ifdef KIO_AVAILABLE
     connect(this->model, &KFilePlacesModel::reloaded, this, &PlacesList::setList);
 
     connect(this->model, &KFilePlacesModel::setupDone, this, &PlacesList::setList);
@@ -97,7 +83,7 @@ PlacesList::PlacesList(QObject *parent)
         emit this->postListChanged();	*/
     }); // TODO improve the usage of the model
 #else
-    connect(&AppSettings::global(), &AppSettings::settingChanged, [&](const QUrl, const QString &key, const QVariant, const QString &group) {
+    connect(&AppSettings::global(), &AppSettings::settingChanged, [this](const QUrl, const QString &key, const QVariant, const QString &group) {
         if (key == "BOOKMARKS" && group == "PREFERENCES") {
             this->setList();
             emit this->bookmarksChanged();
@@ -106,14 +92,6 @@ PlacesList::PlacesList(QObject *parent)
 #endif
 }
 
-void PlacesList::watchPath(const QString &path)
-{
-    if (path.isEmpty() || !FMH::fileExists(path) || !QUrl(path).isLocalFile())
-        return;
-
-    this->watcher->addPath(QUrl(path).toLocalFile());
-}
-
 void PlacesList::componentComplete()
 {
     connect(this, &PlacesList::groupsChanged, this, &PlacesList::setList);
@@ -132,9 +110,9 @@ FMH::MODEL_LIST PlacesList::getGroup(const KFilePlacesModel &model, const FMStat
     if (type == FMStatic::PATHTYPE_KEY::QUICK_PATH) {
         res << FMH::MODEL {{FMH::MODEL_KEY::PATH, FMStatic::PATHTYPE_URI[FMStatic::PATHTYPE_KEY::TAGS_PATH] + "fav"}, {FMH::MODEL_KEY::ICON, "love"}, {FMH::MODEL_KEY::LABEL, "Favorite"}, {FMH::MODEL_KEY::TYPE, "Quick"}};
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-    res << FMH::MODEL {{FMH::MODEL_KEY::PATH, "recentdocuments:///"}, {FMH::MODEL_KEY::ICON, "view-media-recent"}, {FMH::MODEL_KEY::LABEL, "Recent"}, {FMH::MODEL_KEY::TYPE, "Quick"}};
-#endif
+// #ifdef KIO_AVAILABLE
+//     res << FMH::MODEL {{FMH::MODEL_KEY::PATH, "recentdocuments:///"}, {FMH::MODEL_KEY::ICON, "view-media-recent"}, {FMH::MODEL_KEY::LABEL, "Recent"}, {FMH::MODEL_KEY::TYPE, "Quick"}};
+// #endif
 
     res << FMH::MODEL {{FMH::MODEL_KEY::PATH, "tags:///"}, {FMH::MODEL_KEY::ICON, "tag"}, {FMH::MODEL_KEY::LABEL, "Tags"}, {FMH::MODEL_KEY::TYPE, "Quick"}};
 
@@ -143,28 +121,17 @@ FMH::MODEL_LIST PlacesList::getGroup(const KFilePlacesModel &model, const FMStat
 
 if (type == FMStatic::PATHTYPE_KEY::PLACES_PATH) {
     res << FMStatic::getDefaultPaths();
+    return res;
 }
 
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
-Q_UNUSED(model)
-switch (type) {
-    case (FMStatic::PATHTYPE_KEY::PLACES_PATH):
-        res << FMStatic::packItems(UTIL::loadSettings("BOOKMARKS", "PREFERENCES", {}, true).toStringList(), FMStatic::PATHTYPE_LABEL[FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH]);
-        break;
-    case (FMStatic::PATHTYPE_KEY::DRIVES_PATH):
-        res = FMStatic::getDevices();
-        break;
-    default:
-        break;
-}
-#else
-const auto group = model.groupIndexes(static_cast<KFilePlacesModel::GroupType>(type));
+#ifdef KIO_AVAILABLE
+auto mappedType = FMStatic::mapPathType(type);
+
+const auto group = model.groupIndexes(static_cast<KFilePlacesModel::GroupType>(type == FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH ? FMStatic::mapPathType(FMStatic::PATHTYPE_KEY::PLACES_PATH) : mappedType));
+
 res << std::accumulate(group.constBegin(), group.constEnd(), FMH::MODEL_LIST(), [&model, &type, this](FMH::MODEL_LIST &list, const QModelIndex &index) -> FMH::MODEL_LIST {
     const QUrl url = model.url(index);
-    if (type == FMStatic::PATHTYPE_KEY::PLACES_PATH && FMStatic::defaultPaths.contains(url.toString()))
-        return list;
-
-    if (type == FMStatic::PATHTYPE_KEY::PLACES_PATH && url.isLocalFile() && !FMH::fileExists(url))
+    if (type == FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH && FMStatic::defaultPaths.contains(url.toString()))
         return list;
 
     auto data = FMH::MODEL {{FMH::MODEL_KEY::PATH, url.toString()},
@@ -172,7 +139,7 @@ res << std::accumulate(group.constBegin(), group.constEnd(), FMH::MODEL_LIST(),
     {FMH::MODEL_KEY::ICON, model.icon(index).name()},
     {FMH::MODEL_KEY::LABEL, model.text(index)},
     {FMH::MODEL_KEY::NAME, model.text(index)},
-                       {FMH::MODEL_KEY::TYPE, type == FMStatic::PATHTYPE_KEY::PLACES_PATH ? FMStatic::PATHTYPE_LABEL[FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH] : FMStatic::PATHTYPE_LABEL[type]}};
+                       {FMH::MODEL_KEY::TYPE, type == FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH ? FMStatic::PATHTYPE_LABEL[FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH] : FMStatic::PATHTYPE_LABEL[type]}};
 
     if(model.isDevice(index))
     {
@@ -186,6 +153,20 @@ res << std::accumulate(group.constBegin(), group.constEnd(), FMH::MODEL_LIST(),
     list << data;
     return list;
 });
+
+#else
+Q_UNUSED(model)
+switch (type) {
+    case (FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH):
+        res << FMStatic::packItems(UTIL::loadSettings("BOOKMARKS", "PREFERENCES", {}, true).toStringList(), FMStatic::PATHTYPE_LABEL[FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH]);
+        break;
+    case (FMStatic::PATHTYPE_KEY::DRIVES_PATH):
+        res = FMStatic::getDevices();
+        break;
+    default:
+        break;
+}
+
 #endif
 
 return res;
@@ -203,57 +184,39 @@ void PlacesList::setList()
 
     for (const auto &group : qAsConst(this->groups)) {
         switch (group) {
-            case FMStatic::PATHTYPE_KEY::PLACES_PATH:
-                this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::PLACES_PATH);
+        case FMStatic::PATHTYPE_KEY::PLACES_PATH:
+            this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::PLACES_PATH);
+            break;
+            
+        case FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH:
+            this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::BOOKMARKS_PATH);
             break;
 
-            case FMStatic::PATHTYPE_KEY::QUICK_PATH:
-                this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::QUICK_PATH);
+        case FMStatic::PATHTYPE_KEY::QUICK_PATH:
+            this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::QUICK_PATH);
             break;
 
-            case FMStatic::PATHTYPE_KEY::DRIVES_PATH:
-                this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::DRIVES_PATH);
+        case FMStatic::PATHTYPE_KEY::DRIVES_PATH:
+            this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::DRIVES_PATH);
             break;
 
-            case FMStatic::PATHTYPE_KEY::REMOTE_PATH:
-                this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::REMOTE_PATH);
+        case FMStatic::PATHTYPE_KEY::REMOTE_PATH:
+            this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::REMOTE_PATH);
             break;
 
-            case FMStatic::PATHTYPE_KEY::REMOVABLE_PATH:
-                this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::REMOVABLE_PATH);
+        case FMStatic::PATHTYPE_KEY::REMOVABLE_PATH:
+            this->list << getGroup(*this->model, FMStatic::PATHTYPE_KEY::REMOVABLE_PATH);
             break;
 
-            case FMStatic::PATHTYPE_KEY::TAGS_PATH:            
+        case FMStatic::PATHTYPE_KEY::TAGS_PATH:
             this->list << Tagging::getInstance()->getTags();
             break;
-                        
-#ifdef COMPONENT_ACCOUNTS
-            case FMStatic::PATHTYPE_KEY::CLOUD_PATH:
-            this->list << MauiAccounts::instance()->getCloudAccounts();
-            break;
-#endif
         }
     }
 
-    this->setCount();
     emit this->postListChanged();
 }
 
-void PlacesList::setCount()
-{
-    this->watcher->removePaths(this->watcher->directories());
-    for (auto &data : this->list) {
-        const auto path = data[FMH::MODEL_KEY::URL];
-        if (FMStatic::isDir(path)) {
-            data.insert(FMH::MODEL_KEY::COUNT, "0");
-            QDir dir(QUrl(path).toLocalFile());
-            const auto count = dir.count();
-            this->count.insert(path, count);
-            this->watchPath(path);
-        }
-    }
-}
-
 QList<int> PlacesList::getGroups() const
 {
     return this->groups;
@@ -268,35 +231,20 @@ void PlacesList::setGroups(const QList<int> &value)
     emit this->groupsChanged();
 }
 
-QVariantMap PlacesList::get(const int &index) const
-{
-    if (index >= this->list.size() || index < 0)
-        return QVariantMap();
-
-    const auto model = this->list.at(index);
-    return FMH::toMap(model);
-}
-
-void PlacesList::clearBadgeCount(const int &index)
-{
-    this->list[index][FMH::MODEL_KEY::COUNT] = "0";
-    emit this->updateModel(index, {FMH::MODEL_KEY::COUNT});
-}
-
 void PlacesList::removePlace(const int &index)
 {
     if (index >= this->list.size() || index < 0)
         return;
 
-#if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
-    auto bookmarks = UTIL::loadSettings("BOOKMARKS", "PREFERENCES", {}, true).toStringList();
-    bookmarks.removeOne(this->list.at(index)[FMH::MODEL_KEY::PATH]);
-    UTIL::saveSettings("BOOKMARKS", bookmarks, "PREFERENCES", true);
-#else
+#ifdef KIO_AVAILABLE
     emit this->preItemRemoved(index);
     this->model->removePlace(this->model->closestItem(this->list.at(index)[FMH::MODEL_KEY::PATH]));
     this->list.removeAt(index);
     emit this->postItemRemoved();
+#else
+    auto bookmarks = UTIL::loadSettings("BOOKMARKS", "PREFERENCES", {}, true).toStringList();
+    bookmarks.removeOne(this->list.at(index)[FMH::MODEL_KEY::PATH]);
+    UTIL::saveSettings("BOOKMARKS", bookmarks, "PREFERENCES", true);
 #endif
 }
 
@@ -310,7 +258,7 @@ bool PlacesList::isDevice(const int &index)
     if (index >= this->list.size() || index < 0)
         return false;
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#ifdef KIO_AVAILABLE
     const auto item = this->list.at(index);
     return m_devices.contains(item[FMH::MODEL_KEY::UDI]);
 #endif
@@ -323,7 +271,7 @@ bool PlacesList::setupNeeded(const int &index)
     if (index >= this->list.size() || index < 0)
         return false;
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#ifdef KIO_AVAILABLE
     const auto item = this->list.at(index);
     if(m_devices.contains(item[FMH::MODEL_KEY::UDI]))
     {
@@ -339,11 +287,11 @@ void PlacesList::requestEject(const int &index)
     if (index >= this->list.size() || index < 0)
         return;
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#ifdef KIO_AVAILABLE
     const auto item = this->list.at(index);
     if(m_devices.contains(item[FMH::MODEL_KEY::UDI]))
     {
-       this->model->requestEject(m_devices.value(item[FMH::MODEL_KEY::UDI]));
+        this->model->requestEject(m_devices.value(item[FMH::MODEL_KEY::UDI]));
     }
 #endif
 }
@@ -353,29 +301,32 @@ void PlacesList::requestSetup(const int &index)
     if (index >= this->list.size() || index < 0)
         return;
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#ifdef KIO_AVAILABLE
     const auto item = this->list.at(index);
     if(m_devices.contains(item[FMH::MODEL_KEY::UDI]))
     {
-       this->model->requestSetup(m_devices.value(item[FMH::MODEL_KEY::UDI]));
+        this->model->requestSetup(m_devices.value(item[FMH::MODEL_KEY::UDI]));
     }
 #endif
 }
 
 void PlacesList::addBookmark(const QUrl& url)
 {
-    #if defined Q_OS_ANDROID || defined Q_OS_WIN32 || defined Q_OS_MACOS || defined Q_OS_IOS
+#ifdef KIO_AVAILABLE
+    KFilePlacesModel model;
+    model.addPlace(QDir(url.toLocalFile()).dirName(), url, FMStatic::getIconName(url));
+#else
     // do android stuff until cmake works with android
     if (FMStatic::isDefaultPath(url.toString()))
         return;
-    
-        auto bookmarks = UTIL::loadSettings("BOOKMARKS", "PREFERENCES", {}, true).toStringList();
-        bookmarks << url.toString();
-        UTIL::saveSettings("BOOKMARKS", bookmarks, "PREFERENCES", true);
-    #else
-    KFilePlacesModel model;
-    model.addPlace(QDir(url.toLocalFile()).dirName(), url, FMStatic::getIconName(url));
-    #endif
+
+    auto bookmarks = UTIL::loadSettings("BOOKMARKS", "PREFERENCES", {}, true).toStringList();
+    bookmarks << url.toString();
+    UTIL::saveSettings("BOOKMARKS", bookmarks, "PREFERENCES", true);
+#endif
 }
 
-
+int PlacesList::indexOfPath(const QUrl &url) const
+{
+    return this->indexOf(FMH::MODEL_KEY::PATH, url.toString());
+}
