@@ -1,6 +1,6 @@
 #include "thumbnailer.h"
 
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
+#ifdef KIO_AVAILABLE
 #include <KIO/PreviewJob>
 #endif
 
@@ -17,8 +17,9 @@ AsyncImageResponse::AsyncImageResponse(const QString &id, const QSize &requested
     : m_id(id)
     , m_requestedSize(requestedSize)
 {
-#if defined Q_OS_LINUX && !defined Q_OS_ANDROID
-    QStringList plugins = KIO::PreviewJob::defaultPlugins();
+#ifdef KIO_AVAILABLE
+    QStringList plugins = KIO::PreviewJob::availablePlugins();
+//     qDebug() << plugins << KIO::PreviewJob::defaultPlugins();
     auto job = new KIO::PreviewJob(KFileItemList() << KFileItem(QUrl::fromUserInput(id)), requestedSize, &plugins);
 
     connect(job, &KIO::PreviewJob::gotPreview, [this](KFileItem, QPixmap pixmap) {
@@ -27,7 +28,8 @@ AsyncImageResponse::AsyncImageResponse(const QString &id, const QSize &requested
     });
 
     connect(job, &KIO::PreviewJob::failed, [this](KFileItem) {
-        emit this->cancel();
+        m_error = "Thumbnail Previewer job failed";
+        this->cancel();
         emit this->finished();
     });
 
@@ -39,3 +41,8 @@ QQuickTextureFactory *AsyncImageResponse::textureFactory() const
 {
     return QQuickTextureFactory::textureFactoryForImage(m_image);
 }
+
+QString AsyncImageResponse::errorString() const
+{
+    return m_error;
+}
